@@ -46,7 +46,7 @@
  * version number.  Used together with oath_check_version() to verify
  * header file and run-time library consistency.
  */
-#define OATH_VERSION "1.12.5"
+#define OATH_VERSION "1.12.6"
 
 /**
  * OATH_VERSION_NUMBER
@@ -56,7 +56,7 @@
  * this symbol will have the value 0x01020300.  The last two digits
  * are only used between public releases, and will otherwise be 00.
  */
-#define OATH_VERSION_NUMBER 0x010c0500
+#define OATH_VERSION_NUMBER 0x010c0600
 
 /**
  * oath_rc:
@@ -83,6 +83,11 @@
  * @OATH_INVALID_BASE32: Base32 string is invalid
  * @OATH_BASE32_OVERFLOW: Base32 encoding would overflow
  * @OATH_MALLOC_ERROR: Memory allocation failed
+ * @OATH_FILE_FLUSH_ERROR: System error when flushing file buffer
+ * @OATH_FILE_SYNC_ERROR: System error when syncing file to disk
+ * @OATH_FILE_CLOSE_ERROR: System error when closing file
+ * @OATH_LAST_ERROR: Meta-error indicating the last error code, for use
+ *   when iterating over all error codes or similar.
  *
  * Return codes for OATH functions.  All return codes are negative
  * except for the successful code OATH_OK which are guaranteed to be
@@ -115,7 +120,13 @@ typedef enum
   OATH_STRCMP_ERROR = -19,
   OATH_INVALID_BASE32 = -20,
   OATH_BASE32_OVERFLOW = -21,
-  OATH_MALLOC_ERROR = -22
+  OATH_MALLOC_ERROR = -22,
+  OATH_FILE_FLUSH_ERROR = -23,
+  OATH_FILE_SYNC_ERROR = -24,
+  OATH_FILE_CLOSE_ERROR = -25,
+  /* When adding anything here, update OATH_LAST_ERROR, errors.c
+     and tests/tst_errors.c. */
+  OATH_LAST_ERROR = -25
 } oath_rc;
 
 /* Global */
